@@ -3,6 +3,7 @@ package org.irisa.genouest.logol;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.BufferedReader;
+import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
@@ -16,6 +17,7 @@ import java.io.PrintWriter;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -30,6 +32,7 @@ import java.util.jar.Attributes;
 import java.util.jar.Manifest;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.List;
 
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
@@ -146,6 +149,7 @@ class StreamGobbler implements Runnable {
  *          08/06/12 Add check option
  *          12/06/12 FIX 2162 If maxlength=0, set it to sequence size
  *          04/10/13 FIX 2242 Error with overlap
+ *          07/11/13 Add windows support
  */
 public class Logol {
 
@@ -155,6 +159,8 @@ public class Logol {
 	private static final Logger logger = Logger.getLogger(org.irisa.genouest.logol.Logol.class);
 	
 	
+	private static String OS = System.getProperty("os.name").toLowerCase();
+	
 	private static final String FILESEPARATORPROPERTY = "file.separator";
 	
 	
@@ -347,13 +353,15 @@ public class Logol {
 				suffixPath = config.getString("suffix.path");
 			}
 			
-		 	
+			// Manage Windows path
+		 	installPath = installPath.replaceAll("\\\\", "/");
 		 	Treatment.installPath = installPath;
+		 	
 		 	if(suffixTool==1) {
-		 		Treatment.suffixSearchPath=installPath+System.getProperty(FILESEPARATORPROPERTY)+"tools"+System.getProperty(FILESEPARATORPROPERTY)+"suffixSearch.sh";
+		 		Treatment.suffixSearchPath=installPath+"/tools/suffixSearch.rb";
 		 	}
 		 	else {
-		 		Treatment.suffixSearchPath=installPath+System.getProperty(FILESEPARATORPROPERTY)+"tools"+System.getProperty(FILESEPARATORPROPERTY)+"logolSearch.sh";
+		 		Treatment.suffixSearchPath=installPath+"/tools/logolSearch.rb";
 		 	}
 		 	
 		 	savfile = installPath+System.getProperty(FILESEPARATORPROPERTY)+"prolog"+System.getProperty(FILESEPARATORPROPERTY)+"logol.sav";
@@ -435,7 +443,7 @@ public class Logol {
 			File tmpf = new File(outputResultFileName);
 			if(tmpf.getParent()==null) {
 			// If no output directory is specified, use default directory
-				errFile = resultDir+System.getProperty(Constants.FILESEPARATORPROPERTY)+outputResultFileName+".err";
+				errFile = resultDir+'/'+outputResultFileName+".err";
 			}
 			else {
 				// If a directory is specified , use it.
@@ -1064,12 +1072,12 @@ public class Logol {
 	        logger.debug("file transformed and renamed");
 	        
 			String outputResultFile;
-			if(outputResultFileName==null) { outputResultFile = resultDir+System.getProperty(Constants.FILESEPARATORPROPERTY)+mergeFile.getName(); }
+			if(outputResultFileName==null) { outputResultFile = resultDir+'/'+mergeFile.getName(); }
 			else {
 				File tmpf = new File(outputResultFileName);
 				if(tmpf.getParent()==null) {
 				// If no output directory is specified, use default directory
-				outputResultFile = resultDir+System.getProperty(Constants.FILESEPARATORPROPERTY)+outputResultFileName;
+				outputResultFile = resultDir+'/'+outputResultFileName;
 				}
 				else {
 					// If a directory is specified , use it.
@@ -1104,12 +1112,172 @@ public class Logol {
 	}
 
 
+	/**
+	* Search for fixed string with [] , i.e. "complex string" to transform them in views
+	*
+	*/
+	private static String searchForComplexStrings(String grammar) {
+
+        	logger.debug("Search for complex string");
+        	Pattern pcomplex =  Pattern.compile("(([\\+\\-]\".*?\"\\s+)?\".*?\"(:\\{.*?\\})*)");
+        	Matcher mcomplex = pcomplex.matcher(grammar);
+		String modifier = "";
+      		while(mcomplex.find()) {
+        		logger.debug("found = "+mcomplex.groupCount()+", "+ mcomplex.group(1));
+			String complexstring = mcomplex.group(1);
+			String fixed2view = Logol.mapComplexStringToView(complexstring);
+			grammar = grammar.replace(complexstring,fixed2view);
+        	}
+		return grammar;
+	}
+
+	/**
+	* Transform a complex string in a view
+	*/
+	private static String mapComplexStringToView(String complexstring) {
+
+        List<String[]> fixedElts = new ArrayList<String[]>();
+		String[] complexstringElts = complexstring.split(":");
+		String fixedValue = complexstringElts[0];
+		// Modifier ?
+		String modifier = "";
+		String[] modifier_fixed = fixedValue.split("\\s+");
+		if(modifier_fixed.length>1) {
+			modifier = modifier_fixed[0]+" ";
+			fixedValue = modifier_fixed[1];
+		}
+		if(! fixedValue.contains("[")) { return complexstring; }
+
+                fixedValue = fixedValue.replace("\"","");
+                String[] elts = fixedValue.split("\\[");
+                for(int i=0;i<elts.length;i++) {
+                    if(elts[i].equals("")) { continue; }
+                    if(elts[i].contains("]")) {
+                        String closeelts[] = elts[i].split("\\]");
+                        if(closeelts.length>1) {
+                        if(closeelts[0].contains("|")) {
+                            fixedElts.add(closeelts[0].split("\\|"));
+                        }
+                        else {
+                            fixedElts.add(new String[] {closeelts[0]} );
+                            //fixedElts.add(new String[] {closeelts[1]}); 
+                        }
+                        fixedElts.add(new String[] {closeelts[1]});
+                        }
+                        else {
+                        if(closeelts[0].contains("|")) {
+                            fixedElts.add(closeelts[0].split("\\|"));
+                        }
+                        else {
+                             fixedElts.add(new String[] {closeelts[0]}); }
+                        }
+                    }
+                    else {
+                        fixedElts.add(new String[] {elts[i]});
+                    }
+                }
+
+		String fixed2view = "(";
+                boolean first = true;
 
 
+		boolean hasConstraints = false;
+		String beginconstr = null;
+		String endconstr = null;
+		String structconstr = null;
+		if(complexstringElts.length>1) {
+			hasConstraints = true;
+			for(int i=1;i<complexstringElts.length;i++) {
+        			Pattern pconstr =  Pattern.compile("[{,](.*?{1,2}\\[.*?\\])");
+        			Matcher mconstr = pconstr.matcher(complexstringElts[i]);
+      				while(mconstr.find()) {
+					String complexstringEltsConstr = mconstr.group(1);
+					if(complexstringEltsConstr.startsWith("@[")) {
+						// Begin constraint
+						beginconstr = complexstringEltsConstr;
+					}
+					else if(complexstringEltsConstr.startsWith("@@[")) {
+						// End constraint
+						endconstr = complexstringEltsConstr;
+					}
+					else if(complexstringEltsConstr.startsWith("$[") || complexstringEltsConstr.startsWith("$$[")) {
+						// Struct constraint
+						structconstr = complexstringElts[i];
+					}
+				}
+			}
 
-public static void analyse() throws IOException, GrammarException {
-	File fg = new File(grammarFile);
-    InputStream fileGrammar = new BufferedInputStream(new FileInputStream(fg));
+		}
+
+		logger.debug("modifier "+modifier);
+		// Reverse, so need to reverse the list order
+		if(modifier.startsWith("-")) {
+			Collections.reverse(fixedElts);
+		}
+                for(int i=0;i<fixedElts.size();i++) {
+                    if(! first) { fixed2view += ","; }
+
+                    if(fixedElts.get(i).length==1) { 
+                        fixed2view += modifier+"\""+fixedElts.get(i)[0]+"\"";
+                        if(first && beginconstr!=null) { fixed2view += ":{"+beginconstr+"}"; }
+			if(i==fixedElts.size()-1 && endconstr!=null) { fixed2view += ":{"+endconstr+"}"; }
+			if (structconstr!=null) { fixed2view += ":"+structconstr; }
+                    }
+                    else {
+                        boolean firstor = true;
+                        fixed2view += "(";
+                        for(int j=0;j<fixedElts.get(i).length;j++) {
+                        if(! firstor) { fixed2view += "|"; }
+                        fixed2view += modifier+"\""+fixedElts.get(i)[j]+"\"";
+                        if(first && beginconstr!=null) { fixed2view += ":{"+beginconstr+"}"; }
+			if(i==fixedElts.size()-1 && endconstr!=null) { fixed2view += ":{"+endconstr+"}"; }
+			if (structconstr!=null) { fixed2view += ":"+structconstr; }
+                        firstor = false;
+                        }
+                        fixed2view += ")";
+                    } 
+                    first = false;
+                }
+                fixed2view += ")";
+
+		if(complexstringElts.length>1) {
+			for(int i=1;i<complexstringElts.length;i++) {
+				fixed2view += ":"+complexstringElts[i];
+			}
+		}
+
+		return fixed2view;
+
+	}
+
+	/**
+	* Parse the grammar file and performs its analysis to generate prolog
+	*
+	*/
+	public static void analyse() throws IOException, GrammarException {
+
+	String grammarText = null;
+   	BufferedReader br = new BufferedReader(new FileReader(grammarFile));
+    	try {
+        StringBuilder sb = new StringBuilder();
+        String line = br.readLine();
+
+        while (line != null) {
+            sb.append(line);
+            sb.append('\n');
+            line = br.readLine();
+        }
+        grammarText = sb.toString();
+    	} finally {
+        	br.close();
+    	}
+	grammarText = searchForComplexStrings(grammarText);
+	logger.debug("new grammar "+grammarText);
+
+
+	//File fg = new File(grammarFile);
+    	//InputStream fileGrammar = new BufferedInputStream(new FileInputStream(fg));
+	InputStream fileGrammar = new ByteArrayInputStream(grammarText.getBytes());
 	ANTLRInputStream input = new ANTLRInputStream(fileGrammar);
 	logolLexer lexer = new logolLexer(input);
 	CommonTokenStream tokens = new CommonTokenStream(lexer);
@@ -1720,6 +1888,13 @@ private static void clean(Vector<String> jobFiles) {
 		data+=Treatment.getMetaControls();	
 		data+="% **************************\n\n";
 		
+		if(OS.startsWith("win")) {
+			data+=":-assert(logolShell('ruby.exe')).\n";
+		}
+		else {
+			data+=":-assert(logolShell('ruby')).\n";
+		}
+		
 		data+="% ** Main query ************\n";
 		data+=Treatment.query+"\n\n";
 
