@@ -28,6 +28,7 @@ import org.irisa.genouest.logol.utils.LogolUtils;
  * History:
  * 22/08/10 Fix 1664 Unicode issues with special chars
  * 28/04/11 @FIX 1794
+ * 21/10/13 @FIX 2244 length of constraint in Interval can be > 1
  *
  */
 public class Treatment {
@@ -503,8 +504,29 @@ public class Treatment {
 		if(!Character.isDigit(data.charAt(0))) {
 			String[] expression = data.split("\\s");
 			// First character MUST be length constraint #
-			String variable = expression[0].substring(1);
-			String varType = expression[0].substring(0,1);
+			/*  Fix interval constraint analysis where length of constraint can be > 1
+			 * 
+			 * 	public static final String COSTSIGN = "$";
+				public static final String DISTANCESIGN = "$$";
+				public static final String LENGTHSIGN = "#";
+				public static final String CONTENTSIGN = "?";
+				public static final String BEGINSIGN = "@";
+				public static final String ENDSIGN = "@@";
+			 */
+			String[] possibleConstraints = new String[] {Constants.CONTENTSIGN, Constants.DISTANCESIGN, Constants.COSTSIGN, Constants.LENGTHSIGN, Constants.ENDSIGN, Constants.BEGINSIGN};
+			String variable = null;
+			String varType = null;
+			for(int i=0;i<possibleConstraints.length;i++) {
+				if(expression[0].startsWith(possibleConstraints[i])) {
+					variable = expression[0].substring(possibleConstraints[i].length());
+					varType = expression[0].substring(0,possibleConstraints[i].length());
+					break;
+				}
+			}
+			if(variable==null) {
+				logger.error("Could not found a matching constraint in Interval");
+				return null;
+			}
 			if(!Constants.CONTENTSIGN.equals(varType)) {			
 			use += ",((\\+var("+variable+"));(var("+variable+"),"+variable+"='"+model+","+id+","+type+"'))";
 			}
