@@ -56,6 +56,9 @@ public class GrammarTest {
 
 	private static final Logger logger = Logger.getLogger(org.irisa.genouest.logol.test.GrammarTest.class);
 	
+	private static final String OS = System.getProperty("os.name").toLowerCase();
+
+	
 	private static final String FILESEPARATORPROPERTY = "file.separator";
 	
 	private static String sequenceFile= "test.fasta";
@@ -1408,6 +1411,9 @@ public class GrammarTest {
 	 
 	 @Test
 	 public void testMyCost(){
+		 
+		 	assumeTrue(! OS.startsWith("win"));
+		 
 			init();
 
 			Vector<String[]> result = new Vector<String[]>();
@@ -1539,6 +1545,110 @@ public class GrammarTest {
 			
 	 }
 	 
+	 @Test
+	 public void testVMatch2() {
+		 init();
+
+		 String vmatchconfigFile = installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch.properties";
+		 File  lv_file = new File(vmatchconfigFile);
+		 PropertiesConfiguration vmatchconfig  = null;
+	
+		 try {
+			 vmatchconfig = new PropertiesConfiguration(lv_file.getAbsolutePath());
+			} catch (ConfigurationException e1) {
+				fail();
+			}
+		 
+			assumeTrue(vmatchconfig.getInt("suffix.tool")==1);
+			File vmatch = new File(vmatchconfig.getString("suffix.path")+"/vmatch");
+			assumeTrue(vmatch.exists());
+		 
+			Vector<String[]> result = new Vector<String[]>();
+			result.add(new String[] {"LogolVAR_1","1","3"});
+		 		
+			
+			String[] args = new String[] { "-conf",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch.properties" , "-g",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch2.logol" , "-s",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch.fasta", "-max"," 10", "-all"};
+			try {
+				Logol.main(args);
+			} catch (ConfigurationException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			}  catch (InterruptedException e) {
+				fail(e.getMessage());
+			} catch (ParseException e) {
+				fail(e.getMessage());
+			} catch (GrammarException e) {
+				fail(e.getMessage());
+			}
+			
+
+			try {
+				checkResult(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}
+			
+	 }
+	 
+	 @Test
+	 public void testVMatch3() {
+		 init();
+
+		 String vmatchconfigFile = installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch.properties";
+		 File  lv_file = new File(vmatchconfigFile);
+		 PropertiesConfiguration vmatchconfig  = null;
+	
+		 try {
+			 vmatchconfig = new PropertiesConfiguration(lv_file.getAbsolutePath());
+			} catch (ConfigurationException e1) {
+				fail();
+			}
+		 
+			assumeTrue(vmatchconfig.getInt("suffix.tool")==1);
+			File vmatch = new File(vmatchconfig.getString("suffix.path")+"/vmatch");
+			assumeTrue(vmatch.exists());
+		 
+			Vector<String[]> result = new Vector<String[]>();
+			result.add(new String[] {"LogolVAR_1","55","58"});
+		 		
+			
+			String[] args = new String[] { "-conf",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch.properties" , "-g",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch3.logol" , "-s",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"vmatch.fasta", "-max"," 10", "-all"};
+			try {
+				Logol.main(args);
+			} catch (ConfigurationException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			}  catch (InterruptedException e) {
+				fail(e.getMessage());
+			} catch (ParseException e) {
+				fail(e.getMessage());
+			} catch (GrammarException e) {
+				fail(e.getMessage());
+			}
+			
+
+			try {
+				checkResult(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}
+			
+	 }
+	 
 	 @Test
 	 public void testNegContent(){
 			init();
@@ -1686,6 +1796,31 @@ public class GrammarTest {
 			}
 			
 	 }		 
+
+     @Test
+     public void testViewBegin(){
+            init();
+
+            Vector<String[]> result = new Vector<String[]>();
+            result.add(new String[] {"LogolVAR_1","11","14"});
+
+            execute("view_begin.logol");
+
+
+            try {
+                checkResult(result,0);
+            } catch (ParserConfigurationException e) {
+                fail(e.getMessage());
+            } catch (SAXException e) {
+                fail(e.getMessage());
+            } catch (IOException e) {
+                fail(e.getMessage());
+            } catch (TransformerException e) {
+                fail(e.getMessage());
+            }
+
+     }
+
 	 
 		@Test
 		public void testConversion() {
@@ -1724,6 +1859,8 @@ public class GrammarTest {
 		@Test
 		public void testExternal() {
 			
+			assumeTrue(! OS.startsWith("win"));
+			
 			init();
 			
 			Vector<String[]> result = new Vector<String[]>();
@@ -1750,6 +1887,8 @@ public class GrammarTest {
 		@Test
 		public void testExternalWithSpacer() {
 			
+			assumeTrue(! OS.startsWith("win"));
+			
 			init();
 			
 			Vector<String[]> result = new Vector<String[]>();
@@ -2118,6 +2257,51 @@ public class GrammarTest {
 				fail(e.getMessage());
 			}			
 		}
+
+        @Test
+        public void testMorphismVar() {
+
+            init();
+
+            Vector<String[]> result = new Vector<String[]>();
+            result.add(new String[] {"LogolVAR_1","5","5"});
+            execute("test.fasta","morphism_var.logol");
+
+            try {
+                checkResult(result,0);
+            } catch (ParserConfigurationException e) {
+                fail(e.getMessage());
+            } catch (SAXException e) {
+                fail(e.getMessage());
+            } catch (IOException e) {
+                fail(e.getMessage());
+            } catch (TransformerException e) {
+                fail(e.getMessage());
+            }
+        }
+
+        @Test
+        public void testComplexString() {
+
+            init();
+
+            Vector<String[]> result = new Vector<String[]>();
+            result.add(new String[] {"LogolVAR_1","6","9"});
+            execute("test.fasta","complex.logol");
+
+            try {
+                checkResult(result,0);
+            } catch (ParserConfigurationException e) {
+                fail(e.getMessage());
+            } catch (SAXException e) {
+                fail(e.getMessage());
+            } catch (IOException e) {
+                fail(e.getMessage());
+            } catch (TransformerException e) {
+                fail(e.getMessage());
+            }
+        }
+
 		
         /*
         @Test
