@@ -22,6 +22,7 @@ import org.irisa.genouest.logol.utils.LogolUtils;
  * 01/03/10 @FIX 1578
  * 12/10/10 @FIX 1683
  * 25/05/10 @FIX 1800
+ * 11/10/13 @FIX 2243
  */
 public abstract class AbstractVariable {
 
@@ -703,17 +704,17 @@ public abstract class AbstractVariable {
 						}
 						if(Character.isDigit(str.max.charAt(0))) {
 							// If max distance is an integer, add it to max size
-							max=String.valueOf(constrainingVar.fixedValue.length()+Integer.parseInt(str.max));
+							max=String.valueOf(constrainingVar.fixedValue.length()-2+Integer.parseInt(str.max));
 						}
 						else {
 							// If max distance is a variable reference, var may not be known at this time, 
 							// use computation defaults e.g. size * 2 (100% of distance, configurable).
-							max=String.valueOf(Math.round(constrainingVar.fixedValue.length()*Treatment.DEFAULTMAXDISTANCE));
+							max=String.valueOf(Math.round((constrainingVar.fixedValue.length()-2)*Treatment.DEFAULTMAXDISTANCE));
 						}
 						if(Character.isDigit(str.min.charAt(0))) {
 							// If min distance is an integer , reduce min size, minimum is "minLength".
-							if(constrainingVar.fixedValue.length()>Integer.parseInt(str.min)) {
-							min=String.valueOf(constrainingVar.fixedValue.length()-Integer.parseInt(str.min));
+							if(constrainingVar.fixedValue.length()-2>Integer.parseInt(str.min)) {
+							min=String.valueOf(constrainingVar.fixedValue.length()-2-Integer.parseInt(str.min));
 							}
 							else {
 								min=String.valueOf(Treatment.minLength);
@@ -727,8 +728,9 @@ public abstract class AbstractVariable {
 					}
 					else {
 						// If no distance constraint, then use same size as word
-						min=String.valueOf(constrainingVar.fixedValue.length());
-						max=String.valueOf(constrainingVar.fixedValue.length());
+						// @Fix 2243: Remove 2 because fixedValue has quotes around it
+						min=String.valueOf(constrainingVar.fixedValue.length()-2);
+						max=String.valueOf(constrainingVar.fixedValue.length()-2);
 					}
 				
 				
@@ -781,8 +783,8 @@ public abstract class AbstractVariable {
 			if(!Constants.EMPTYSTRING.equals(Treatment.isAnyMin)) { spacerMin = Treatment.isAnyMin; }
 			if(!Constants.EMPTYSTRING.equals(Treatment.isAnyMax) && !Constants.SEQUENCELength.equals(Treatment.isAnyMax)) { spacerMax = Treatment.isAnyMax; }
 			else {
-				spacerMax = LogolUtils.getTemporaryVariable();
-				prologSentence += ",length("+Constants.LOGOLVARBEFORE+varID+","+spacerMax+")";
+				//spacerMax = LogolUtils.getTemporaryVariable();
+				//prologSentence += ",length("+Constants.LOGOLVARBEFORE+varID+","+spacerMax+")";
 			}
 			
 			prologSentence += ",anySpacer_pos("+Constants.LOGOLVARBEFORE+varID+","+Constants.LOGOLVARAFTER+varID+","+SpacerPredicate+",1,"+spacerMin+","+spacerMax+","+Constants.LOGOLVARSPACER+varID+")";
@@ -892,8 +894,8 @@ public abstract class AbstractVariable {
 			if(!Constants.EMPTYSTRING.equals(Treatment.isAnyMin)) { spacerMin = Treatment.isAnyMin; }
 			if(!Constants.EMPTYSTRING.equals(Treatment.isAnyMax) && !Constants.SEQUENCELength.equals(Treatment.isAnyMax)) { spacerMax = Treatment.isAnyMax; }
 			else {
-				spacerMax = LogolUtils.getTemporaryVariable();
-				prologSentence += ",length("+Constants.LOGOLVARBEFORE+varID+","+spacerMax+")";
+				//spacerMax = LogolUtils.getTemporaryVariable();
+				//prologSentence += ",length("+Constants.LOGOLVARBEFORE+varID+","+spacerMax+")";
 			}
 			
 			prologSentence += ",anySpacer_pos("+Constants.LOGOLVARBEFORE+varID+","+Constants.LOGOLVARAFTER+varID+","+SpacerPredicate+",1,"+spacerMin+","+spacerMax+","+Constants.LOGOLVARSPACER+varID+")";
