@@ -672,7 +672,7 @@ public class Variable extends AbstractVariable{
 		
 		
 
-		String dir=Treatment.workingDir+System.getProperty(Constants.FILESEPARATORPROPERTY);
+		//String dir=Treatment.workingDir+System.getProperty(Constants.FILESEPARATORPROPERTY);
 		//if(!workingDir.endsWith("/")) { dir += "/"; }
 		
 
@@ -851,7 +851,7 @@ public class Variable extends AbstractVariable{
 				//isexactwithdistinctgapanderror_pos(InputPos,[E1 | E2], MaxError, MaxDistance, Errors, DistanceErrors, OutPos)
 				prologSentence+=",isexactwithdistinctgapanderror_pos("+matchpos+","+motif+",0, "+distance+", "+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARINDEL+varID+","+Constants.LOGOLVARAFTER+varID+")";
 				prologSentence += ","+Constants.LOGOLVARERRORS+varID+"=0";
-				prologSentence+=","+Constants.LOGOLVARERRORS+varID+">="+mindistance;
+				prologSentence+=","+Constants.LOGOLVARINDEL+varID+">="+mindistance;
 			}
 			// Cost but no distance
 			if(Constants.EMPTYSTRING.equals(distance) && !Constants.EMPTYSTRING.equals(cost)){
@@ -1289,7 +1289,7 @@ public class Variable extends AbstractVariable{
 			/*
 			 * WARNING specific cost function program must be installed under tools directory
 			 */
-			prologSentence+=",myCost('"+Treatment.installPath+System.getProperty(Constants.FILESEPARATORPROPERTY)+"tools"+System.getProperty(Constants.FILESEPARATORPROPERTY)+userSpecificCostFunction.name+"',"+wordContent+","+userCost+","+Constants.LOGOLVARERRORS+varID+")";
+			prologSentence+=",myCost('"+Treatment.installPath+"/tools/"+userSpecificCostFunction.name+"',"+wordContent+","+userCost+","+Constants.LOGOLVARERRORS+varID+")";
 			// Distance do not apply to cost function, set value to zero
 			prologSentence += ","+Constants.LOGOLVARINDEL+varID+"=0";
 		}
